# romer_midibot PYTHON API 

This is the Python API for MIDIbot. It can be used as a stand-alone Python API to perform basic interactions with MIDIbot or together with ROS2 packages for more complex tasks.
